#ifndef NT2_INCLUDE_FUNCTIONS_ACOS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOS_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acos.hpp>

#endif
